@@ -1,10 +1,11 @@
 import inspect
 import time
-from typing import List, Optional, Union
+from typing import Iterator, List, Optional, Union
 
 from selenium.common.exceptions import TimeoutException
 
-from .request import Request
+from seleniumwire import har
+from seleniumwire.request import Request
 
 
 class InspectRequestsMixin:
@@ -28,6 +29,13 @@ class InspectRequestsMixin:
     def requests(self):
         self.proxy.storage.clear_requests()
 
+    def iter_requests(self) -> Iterator[Request]:
+        """Return an iterator of requests.
+
+        Returns: An iterator.
+        """
+        yield from self.proxy.storage.iter_requests()
+
     @property
     def last_request(self) -> Optional[Request]:
         """Retrieve the last request made between the browser and server.
@@ -76,6 +84,17 @@ class InspectRequestsMixin:
             'Timed out after {}s waiting for request matching {}'.format(timeout, pat)
         )
 
+    @property
+    def har(self) -> str:
+        """Get a HAR archive of HTTP transactions that have taken place.
+
+        Note that the enable_har option needs to be set before HAR
+        data will be captured.
+
+        Returns: A JSON string of HAR data.
+        """
+        return har.generate_har(self.proxy.storage.load_har_entries())
+
     @property
     def header_overrides(self):
         """The header overrides for outgoing browser requests.
