@@ -282,7 +282,7 @@ class MitmProxy:
 
             args['mode'] = 'upstream:{}://{}'.format(scheme, hostport)
 
-            if username and password:
+            if username:
                 args['upstream_auth'] = '{}:{}'.format(username, password)
 
         return args
@@ -292,4 +292,4 @@ class SendToLogger:
 
     def log(self, entry):
         """Send a mitmproxy log message through our own logger."""
-        getattr(logger, entry.level, logger.info)(entry.msg)
+        getattr(logger, entry.level.replace('warn', 'warning'), logger.info)(entry.msg)
