@@ -10,6 +10,7 @@ from unittest.mock import patch
 import pytest
 from selenium.common.exceptions import TimeoutException
 
+import seleniumwire
 from seleniumwire import webdriver
 from seleniumwire.thirdparty.mitmproxy.exceptions import ServerException
 from tests import utils as testutils
@@ -377,12 +378,11 @@ def test_upstream_socks_proxy(driver_path, chrome_options, httpbin, socksproxy):
     driver.quit()
 
 
-@pytest.mark.skip('Skipping until no_proxy option has been fixed')
 def test_bypass_upstream_http_proxy(driver_path, chrome_options, httpbin, httpproxy):
     sw_options = {
         'proxy': {
             'https': f'{httpproxy}',
-            'no_proxy': 'localhost'
+            'no_proxy': 'localhost:8085'
         }
     }
 
@@ -518,3 +518,34 @@ def test_address_in_use(driver_path, chrome_options, httpbin):
         create_driver(driver_path, chrome_options, sw_options)
 
     driver.quit()
+
+
+def test_har(driver_path, chrome_options, httpbin):
+    driver = create_driver(
+        driver_path,
+        chrome_options,
+        {'enable_har': True}
+    )
+    driver.get(f'{httpbin}/html')
+
+    har = json.loads(driver.har)
+
+    assert har['log']['creator']['comment'] == f'Selenium Wire version {seleniumwire.__version__}'
+    assert len(har['log']['entries']) == 1
+    assert har['log']['entries'][0]['request']['url'] == f'{httpbin}/html'
+    assert har['log']['entries'][0]['response']['status'] == 200
+
+    driver.quit()
+
+
+def test_disable_capture(driver_path, chrome_options, httpbin):
+    sw_options = {
+        'disable_capture': True
+    }
+
+    driver = create_driver(driver_path, chrome_options, sw_options)
+    driver.get(f'{httpbin}/html')
+
+    assert not driver.requests
+
+    driver.quit()
